/*
Pluck: an open source trivia game for Android

Copyright (C) 2021 Joguitos do luca0N!

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <https://www.gnu.org/licenses/>.

This game is a fork of LibreTrivia, and its source code is available at
<https://github.com/tryton-vanmeer/LibreTrivia>.

Contact us at <joguitos+pluck@luca0n.com>.
*/

package com.luca0n.joguitos.pluck.trivia;

import java.io.Serializable;
import java.util.List;

public class TriviaGame implements Serializable {
	private int currentQuestion;
	private final boolean[] results;
	private final List<TriviaQuestion> questions;
	private final long startEpoch;
	private long endEpoch = -1;

	public TriviaGame(List<TriviaQuestion> questions) {
		this.currentQuestion = 0;
		this.questions = questions;
		this.results = new boolean[questions.size()];
		this.startEpoch = System.currentTimeMillis();
	}

	/**
	 * @return The time this trivia game started in a UNIX timestamp format.
	 * @since 2021-03-17
	 */
	public long getStartEpoch(){
		return this.startEpoch;
	}
	/**
	 * @return The time this trivia game ended in a UNIX timestamp format. If the player is still playing the game, the return will be equal to -1.
	 * @since 2021-03-17
	 */
	public long getEndEpoch(){
		return this.endEpoch;
	}

	public TriviaQuestion getCurrentQuestion() {
		return this.questions.get(currentQuestion);
	}

	public int getQuestionProgress() {
		return this.currentQuestion + 1;
	}

	public int getQuestionsCount() {
		return this.questions.size();
	}

	public boolean[] getResults() {
		return this.results;
	}

	public boolean nextQuestion(String guess) {
		TriviaQuestion question = getCurrentQuestion();
		boolean answer = question.checkAnswer(guess);

		results[currentQuestion] = answer;
		currentQuestion++;

		return answer;
	}

	public boolean isDone() {
		boolean isDone = this.currentQuestion == questions.size();
		// Check isDone and set the trivia game end epoch if the endEpoch field was not yet changed if it's true.
		if (isDone && endEpoch == -1)
			this.endEpoch = System.currentTimeMillis();
		return isDone;
	}
}
